# Discord-Emotes
Use it to get gif for commands like pat, slap, poke, hug and more!!!!

# Installation <img src="https://cdn.discordapp.com/emojis/316264057659326464.png?v=1" alt = "🖥" width="35px">

```powershell
pip install Discord-Emotes
```

# Usage <img src="https://cdn.discordapp.com/emojis/757399420319825950.png?v=1" alt = "✏" width="35px">

```python
from Discord-Emotes import smug, hug, kiss, pat, poke, slap, tickle, neko, ngif, cuddle

smug()
hug()
kiss()
pat()
poke()
slap()
tickle()
neko()
ngif()
cuddle()
```
All these functions will return a gif related to the function. <br>
You can use them anywhere you want.

# Other emotes <img src="https://cdn.discordapp.com/emojis/781428090454147092.gif?v=1" alt = "✏" width="35px">
 Names of all the functions <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> hug <br> 
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> kiss <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> pat <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> poke <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> slap <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> tickle <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> smug <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> cuddle <br>
<img src="https://cdn.discordapp.com/emojis/582077820843327490.png?v=1" alt = "📝" width="15px"> dog <br>

# Like the package? <img src="https://cdn.discordapp.com/emojis/599598716521021441.gif?v=1" alt = "✏" width="35px">
<a href = "https://www.buymeacoffee.com/TheRamann">
Support the creator here
</a>
